@@ -56,6 +56,10 @@ _decsync_new_c.argtypes = [POINTER(c_void_p), c_char_p, c_char_p, c_char_p, c_ch
 _decsync_new_c.restype = c_int
 _decsync_new_c.errcheck = _errcheckDecsync
 
+_decsync_init_done_c = _libdecsync.decsync_so_init_done
+_decsync_init_done_c.argtypes = [c_void_p]
+_decsync_init_done_c.restype = c_void_p
+
 _decsync_free_c = _libdecsync.decsync_so_free
 _decsync_free_c.argtypes = [c_void_p]
 _decsync_free_c.restype = None
@@ -282,6 +286,15 @@ class Decsync:
             collection = ""
         _decsync_new_c(byref(self.ptr), decsync_dir.encode(), sync_type.encode(), collection.encode(), own_app_id.encode())
 
+    def init_done(self):
+        """
+        Marks the DecSync instance as finalized. This function has to be called after adding all the
+        listeners, otherwise the DecSync instance cannot be used from other threads. However, this call
+        only makes it possible to use the instance from other threads, but does not make it safe to have
+        such concurrent calls. For this, it is still necessary to use a mutex for example.
+        """
+        _decsync_init_done_c(self.ptr)
+
     def add_listener(self, subpath, on_entry_update):
         """
         Adds a listener, which describes the actions to execute on some updated entries.
@@ -347,7 +360,7 @@ class Decsync:
         :type entries: list(Entry)
 
         """
-        entries_c = _c_array(c_void_p, list(map(Entry.ptr, entries)))
+        entries_c = _c_array(c_void_p, list(map(lambda x: x.ptr, entries)))
         _set_entries_for_path_c(self.ptr, *_c_path(path), *entries_c)
 
     def execute_all_new_entries(self, extra):
@@ -381,7 +394,7 @@ class Decsync:
         :param extra: extra userdata passed to the listener.
 
         """
-        stored_entries_c = _c_array(c_void_p, list(map(StoredEntry.ptr, stored_entries)))
+        stored_entries_c = _c_array(c_void_p, list(map(lambda x: x.ptr, stored_entries)))
         _execute_stored_entries_c(self.ptr, *stored_entries_c, extra)
 
     def execute_stored_entries_for_path_exact(self, path, extra, keys=None):
